@@ -1,6 +1,6 @@
 ;;; Communication and interface routines for the TkEmacs widget
 ;;;
-;;; $Header: tk-comm.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $
+;;; $Header: tk-comm.el[14.0] Wed Aug  2 11:12:17 1995 sven@(none) frozen $
 ;;;
 ;;; Functions meant to be exported:
 ;;;   - tk-advise-destroy-widget-on-exit:  make Emacs destroy widget on exit
@@ -84,7 +84,7 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 ;;; Variables
 
 (defconst tk-comm-AtFS-Header
-  "$Header: tk-comm.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $")
+  "$Header: tk-comm.el[14.0] Wed Aug  2 11:12:17 1995 sven@(none) frozen $")
 
 (defvar tk-comm-initialized nil
   "If non-nil, the Tk communication module has already been initialized.")
@@ -399,7 +399,7 @@ placed in kill-emacs-hook."
 
 (defun tk-advise-destroy-widget-on-exit ()
   "Advise Emacs to destroy the widget on exit. Does not yet work.
-This is necessary for XfEmacs."
+This is necessary for TkEmacs."
   (setq tk-kill-widget-on-exit t))
 
 
