@@ -1,6 +1,6 @@
 ;;; Functions for the TkEmacs widget.
 ;;;
-;;; $Header: tk-funcs.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $
+;;; $Header: tk-funcs.el[14.0] Sat Jan 20 12:54:57 1996 sven@(none) frozen $
 ;;;
 ;;; Functions meant to be exported:
 ;;;   - tk-get-buffer-string:  get contents (or part of it) of curr. buffer
@@ -54,7 +54,7 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 (provide 'tk-funcs)
 
 (defconst tk-funcs-AtFS-Header
-  "$Header: tk-funcs.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $")
+  "$Header: tk-funcs.el[9.1] Tue Nov  1 17:03:00 1994 garfield@mydomain.de frozen $")
 
 
 ;;; variables
@@ -83,12 +83,27 @@ third the number of lines in this buffer,
 fourth the number of the first window-line.")
 
 (defconst tk-emacs-type
-  (cond ((string-match "Lucid" (emacs-version)) 'lucid-19)
+  (cond ((string-match "19.[1-9][0-9][.0-9]* Lucid" (emacs-version)) 'lucid-19New)
+        ((string-match "19.[1-9][0-9][.0-9]* XEmacs Lucid" (emacs-version)) 'lucid-19New)
+	((string-match "XEmacs 19.[1-9][0-9][.0-9]*" (emacs-version)) 'lucid-19New)
+        ((string-match "Lucid" (emacs-version)) 'lucid-19)
+        ((string-match "GNU Emacs 19.2[5-9]" (emacs-version)) 'gnu-19New)
+        ((string-match "GNU Emacs 19.[3-9][0-9]" (emacs-version)) 'gnu-19New)
         ((string-match "GNU Emacs 19" (emacs-version)) 'gnu-19)
 	((string-match "GNU Emacs 18" (emacs-version)) 'gnu-18)
 	(t (error "Unknown Emacs type")))
   "Type of Emacs that runs this TkEmacs code.")
 
+;;; uncomment this definition if you have problems reparenting emacs,
+;;; and set the value to either:
+;;;   'gnu-18
+;;;   'gnu-19
+;;;   'gnu-19New
+;;;   'lucid-19
+;;;   'lucid-19New
+;;; so just play around and see which definition works for you.
+;(defconst tk-emacs-type 'gnu-19New)
+
 
 ;;; utility functions
 
@@ -441,13 +456,23 @@ LINE is set the first line of the window."
 (defun tk-reparent ()
   "Reparent emacs window."
   (let ((emacs-version-string (emacs-version)))
-  (cond ((eq tk-emacs-type 'lucid-19)
-         (tk-send-command (format "%s reparentLEmacs %s"
+  (cond ((eq tk-emacs-type 'lucid-19New)
+         (tk-send-command (format "%s reparent2 %s"
 				  tk-widget-name
 				  (x-window-id
 				   (selected-screen)))))
+       ((eq tk-emacs-type 'lucid-19)
+         (tk-send-command (format "%s reparent3 %s"
+				  tk-widget-name
+				  (x-window-id
+				   (selected-screen)))))
+        ((eq tk-emacs-type 'gnu-19New)
+         (tk-send-command (format "%s reparent2 %s"
+			     tk-widget-name
+			     (cdr (assq 'window-id (frame-parameters 
+						    (selected-frame)))))))
         ((eq tk-emacs-type 'gnu-19)
-         (tk-send-command (format "%s reparentEmacs19 %s"
+         (tk-send-command (format "%s reparent0 %s"
 			     tk-widget-name
 			     (cdr (assq 'window-id (frame-parameters 
 						    (selected-frame)))))))
@@ -474,17 +499,25 @@ e.g. Minibuffers.)"
 
 (defun tk-set-background (color)
   "Set background color."
-  (cond ((eq tk-emacs-type 'lucid-19)
-	   (set-face-background 'default color))
-	  ((eq tk-emacs-type 'gnu-19)
-	   (set-background-color color))
-	  ((eq tk-emacs-type 'gnu-18)
-	   (x-set-background-color color))))
+  (cond ((eq tk-emacs-type 'lucid-19New)
+	 (set-face-background 'default color))
+	((eq tk-emacs-type 'lucid-19)
+	 (set-face-background 'default color))
+	((eq tk-emacs-type 'gnu-19New)
+	 (set-background-color color))
+	((eq tk-emacs-type 'gnu-19)
+	 (set-background-color color))
+	((eq tk-emacs-type 'gnu-18)
+	 (x-set-background-color color))))
 
 (defun tk-set-foreground (color)
   "Set foreground color."
-  (cond ((eq tk-emacs-type 'lucid-19)
+  (cond ((eq tk-emacs-type 'lucid-19New)
 	 (set-face-foreground 'default color))
+        ((eq tk-emacs-type 'lucid-19)
+	 (set-face-foreground 'default color))
+	((eq tk-emacs-type 'gnu-19New)
+	 (set-foreground-color color))
 	((eq tk-emacs-type 'gnu-19)
 	 (set-foreground-color color))
 	((eq tk-emacs-type 'gnu-18)
@@ -492,7 +525,10 @@ e.g. Minibuffers.)"
 
 (defun tk-set-cursor-background (color)
   "Set cursor color."
-  (cond ((eq tk-emacs-type 'lucid-19)
+  (cond ((eq tk-emacs-type 'lucid-19New))
+        ((eq tk-emacs-type 'lucid-19)
+         (set-cursor-color color))
+        ((eq tk-emacs-type 'gnu-19New)
          (set-cursor-color color))
         ((eq tk-emacs-type 'gnu-19)
          (set-cursor-color color))
@@ -501,8 +537,12 @@ e.g. Minibuffers.)"
 
 (defun tk-set-highlight-background (color)
   "Set highlight background color."
-  (cond ((eq tk-emacs-type 'lucid-19)
+  (cond ((eq tk-emacs-type 'lucid-19New)
          (set-face-background 'primary-selection color))
+        ((eq tk-emacs-type 'lucid-19)
+         (set-face-background 'primary-selection color))
+        ((eq tk-emacs-type 'gnu-19New)
+         (set-face-background 'highlight color))
         ((eq tk-emacs-type 'gnu-19)
          (set-face-background 'highlight color))
         ((eq tk-emacs-type 'gnu-18)
@@ -511,8 +551,12 @@ e.g. Minibuffers.)"
 
 (defun tk-set-highlight-foreground (color)
   "Set highlight foreground color."
-  (cond ((eq tk-emacs-type 'lucid-19)
+  (cond ((eq tk-emacs-type 'lucid-19New)
          (set-face-foreground 'primary-selection color))
+        ((eq tk-emacs-type 'lucid-19)
+         (set-face-foreground 'primary-selection color))
+        ((eq tk-emacs-type 'gnu-19New)
+         (set-face-foreground 'highlight color))
         ((eq tk-emacs-type 'gnu-19)
          (set-face-foreground 'highlight color))
         ((eq tk-emacs-type 'gnu-18)
@@ -521,7 +565,11 @@ e.g. Minibuffers.)"
 
 (defun tk-set-font (font)
   "Set font."
-  (cond ((eq tk-emacs-type 'lucid-19)
+  (cond ((eq tk-emacs-type 'lucid-19New)
+         (set-face-font  'default font))
+        ((eq tk-emacs-type 'lucid-19)
+         (set-default-font font))
+        ((eq tk-emacs-type 'gnu-19New)
          (set-default-font font))
         ((eq tk-emacs-type 'gnu-19)
          (set-default-font font))
@@ -530,7 +578,9 @@ e.g. Minibuffers.)"
 
 (defun tk-set-border-width-to-zero ()
   "Set border width to zero."
-  (cond ((eq tk-emacs-type 'lucid-19))
+  (cond ((eq tk-emacs-type 'lucid-19New))
+        ((eq tk-emacs-type 'lucid-19))
+        ((eq tk-emacs-type 'gnu-19New))
         ((eq tk-emacs-type 'gnu-19))
         ((eq tk-emacs-type 'gnu-18)
          (x-set-border-width 0)
