@@ -1,6 +1,6 @@
 ;;; Load file for TkEmacs widget support
 ;;;
-;;; $Header: tkemacs.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $
+;;; $Header: tkemacs.el[14.0] Fri Dec  9 03:19:36 1994 garfield@mydomain.de frozen $
 ;;; 
 ;;;
 ;;; All files for the TkEmacs widget are loaded from here:
@@ -28,7 +28,13 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 ")
 
 (defconst tkemacs-AtFS-Header
-  "$Header: tkemacs.el[4.0] Wed May  4 23:54:55 1994 garfield@mydomain.de frozen $")
+  "$Header: tkemacs.el[14.0] Fri Dec  9 03:19:36 1994 garfield@mydomain.de frozen $")
+
+;; To disable the menubar under emacs 19 uncomment the following line
+;(menu-bar-mode 0)
+
+;; To disable the menubar under xemacs 19 uncomment the following line
+;(setq current-menubar ())
 
 (require 'tk-comm)
 (require 'tk-funcs)
